# R script accompanying "Capturing temporal heterogeneity in soil nitrous oxide fluxes with a robust and low-cost automated chamber apparatus"
# Nathaniel C. Lawrence and Steven J. Hall

#this script was developed using R 3.6.0, and used the packages lubridate v1.7.4,nlme v3.1-140, reshape v0.8.8


## HOW TO USE: download R project and set working directory to project directory

#remove old data
rm(list=ls())

#install these packages as necessary, and load them
library(lubridate)
library(nlme)
library(reshape)

## ## load datafile from Campbell CR3000 datlogger. This recorded ten second averages of all variables required to calculate gas fluxes. We will load in two steps. First time, just grab the column headings and initial data (first 10 rows). A "skip = x" may need to be adjusted if not using the example dataset.
CR_Datafile<-read.table("Example_Dataset.csv", sep = ",", na.strings="NAN", header=TRUE, nrows=10)



# # define a vector for column names
col.names<-names(CR_Datafile)

#now get the whole dataset, the "skip" may need to be adjusted if not using the example dataset.
CR_Datafile_2<-read.csv("Example_Dataset.csv",
                  skip=3, na.strings="NAN",
                  header=TRUE, col.names=col.names)
View(CR_Datafile_2)

#define a new data frame that we will modify
logger<-CR_Datafile_2

#define time; see ?strptime for help on defining date/time classes.
#Make sure that seconds are included in the time created. If the example dataset was opened or saved with excel, the resulting timestamp will not include seconds and the remainder of the script will not run.
logger$time<-as.POSIXct(strptime(logger$TIMESTAMP, "%Y-%m-%d %H:%M:%S"),tz="America/Chicago")

#Create time variables
logger$minute<-minute(logger$time)
logger$hour<-hour(logger$time)
logger$second<-second(logger$time)
logger$seconds_inhour<-logger$second+logger$minute*60
logger$date<-as.Date(logger$time, tz="America/Chicago")
logger$date.hour<- paste(logger$date, logger$hour)
logger$date.hour.min<- paste(logger$date, logger$hour, logger$minute)

#define a vector of hours in two-hour chunks  for subsequent standard calibrations ("std" will denote standards)
logger$cal.hour<-logger$hour
logger$cal.hour[logger$cal.hour==1]<-0
logger$cal.hour[logger$cal.hour==3]<-2
logger$cal.hour[logger$cal.hour==5]<-4
logger$cal.hour[logger$cal.hour==7]<-6
logger$cal.hour[logger$cal.hour==9]<-8
logger$cal.hour[logger$cal.hour==11]<-10
logger$cal.hour[logger$cal.hour==13]<-12
logger$cal.hour[logger$cal.hour==15]<-14
logger$cal.hour[logger$cal.hour==17]<-16
logger$cal.hour[logger$cal.hour==19]<-18
logger$cal.hour[logger$cal.hour==21]<-20
logger$cal.hour[logger$cal.hour==23]<-22

#define cumulative hours of operation, this is valuable to remove times when the N2O analyzer is warming up
logger$cum.hours<-as.numeric(floor(difftime(logger$time, floor_date(logger$time[1], "hour"), units=c("hours")))+1)

#Can reduce the dataset to remove problems, this is an easy step to come back to and remove problems that are found further down the script, here we'll keep the whole dataset

#red<-logger[logger$time>=as.POSIXct("2019-08-01 00:00:00 CST")& logger$time<=as.POSIXct("2019-08-05 02:00:00 CST"),]

red<-logger


#remove timeperiods when analyzer has been on for less than one hour for warm-up. In cool weather, more time may need to be removed. The previous step is useful for this
short<-tapply(red$seconds_inhour, red$date.hour, length)
short1<-short[short<360]
shorter<-names(short1)
red1<-red
red2<-red1[!(red1$date.hour %in% shorter),]
red2<-red2[order(red2$time),]




# each hour involves measurements of two plots, one each during the first and second halves of the hour.

#standards are measured at the top of the hour, every two hours.

#look at hourly traces for each plot pair, in hours where standards are measured, we see low standard, high standard, inlet and outlet measurements as described in Figure 6.
#all valves are off for one minute at the end of each half hour. 

#If the example dataset was opened or saved with excel, attempting to plot will result in an error message. See line #35.

#Ch1, 5 with standards
plot(N2O_ppm_Avg ~seconds_inhour, red2[(red2$hour==0),], 
     type='l')
for (i in c(4,8,12,16,20))lines(N2O_ppm_Avg ~seconds_inhour,
                                data=red2[(red2$hour==i),] )


#Ch3, 7
plot(N2O_ppm_Avg ~seconds_inhour, red2[(red2$hour==1),], 
     type='l')
for (i in c(5,9,13,17,21))lines(N2O_ppm_Avg ~seconds_inhour,
                                data=red2[(red2$hour==i),] )

#Ch2, 6 with standards
plot(N2O_ppm_Avg ~seconds_inhour, red2[(red2$hour==2),], 
     type='l')
for (i in c(6,10,14,18,22))lines(N2O_ppm_Avg ~seconds_inhour,
                                 data=red2[(red2$hour==i),] )

#Ch4, 8
plot(N2O_ppm_Avg ~seconds_inhour, red2[(red2$hour==3),], 
     type='l')
for (i in c(7,11,15,19,23))lines(N2O_ppm_Avg ~seconds_inhour,
                                 data=red2[(red2$hour==i),] )


#we can also look at CO2 output from the same time periods, CO2 is often more useful for diagnosing problems because the flux is generally higher

#Ch1, 5 with standards
plot(CO2_ppm_IRGA_Avg ~seconds_inhour, red2[(red2$hour==0),], 
     type='l')
for (i in c(4,8,12,16,20))lines(CO2_ppm_IRGA_Avg ~seconds_inhour,
                                data=red2[(red2$hour==i),] )


#Ch3, 7
plot(CO2_ppm_IRGA_Avg ~seconds_inhour, red2[(red2$hour==1),], 
     type='l')
for (i in c(5,9,13,17,21))lines(CO2_ppm_IRGA_Avg ~seconds_inhour,
                                data=red2[(red2$hour==i),] )

#Ch2, 6 with standards
plot(CO2_ppm_IRGA_Avg ~seconds_inhour, red2[(red2$hour==2),], 
     type='l')
for (i in c(6,10,14,18,22))lines(CO2_ppm_IRGA_Avg ~seconds_inhour,
                                 data=red2[(red2$hour==i),] )

#Ch4, 8
plot(CO2_ppm_IRGA_Avg ~seconds_inhour, red2[(red2$hour==3),], 
     type='l')
for (i in c(7,11,15,19,23))lines(CO2_ppm_IRGA_Avg ~seconds_inhour,
                                 data=red2[(red2$hour==i),] )



###sampling schedule
#stds measured before plots 1 and 2 (every two hours)
# ' HH  Chamber (top of the hour measurements, then the half hour measurements)
#  ' 0  1,5 
# ' 1  3,7
# ' 2  2,6
# ' 3  4,8
# ' 4  1,5
# ' 5  3,7
# ' 6  2,6
# ' 7  4,8
# ' 8  1,5
# ' 9  3,7
# ' 10 2,6
# ' 11 4,8
# ' 12 1,5
# ' 13 3,7
# ' 14 2,6
# ' 15 4,8
# ' 16 1,5
# ' 17 3,7
# ' 18 2,6
# ' 19 4,8
# ' 20 1,5
# ' 21 3,7
# ' 22 2,6
# ' 23 4,8


# Plot the Gas flow rates from the mass flow controllers over time (the function of each mass flow controller is indicated in Figure 5). Consistent flow rate at the desired setpoint (e.g. 1750 ml minute-1) indicates that pumps/valves are working properly. Spikes are due to one minute periods where the pumps turn off/on between chamber measurements
plot(InletFlow_Avg ~time, red2, type='l')
plot(ChFlow_Avg ~time, red2, type='l') #ChFlow = Outlet Flow
plot(SampleFlow_Avg ~time, red2, type='l') # the inlets/outlets of the chamber are subsampled before entering the analyzers, which is why the flow rate decreases relative to the previous plots
plot(N2O_ppm_Avg~time, red2, type='l')
plot(CO2_ppm_IRGA_Avg~time, red2, type='l')

#It can also be useful to look at the air temperature over the measurement period. N2O analyzer output is impacted by temperature as described in section 3.2 (Measurement Assumptions)
plot(AirTC_Avg ~time, red2, type='l')


######## code for averaging components of the measurement cycle over time #######

### ChA corresponds to chamber measured at the top of each hour, ChB for the chamber measured beginning at half past each hour.

#define stage of measurement; shed is default (short, transient periods between useful output). "shed" denotes when air from the instrument shed is entering the analyzer.

#the labels for each remaining stage coincide with section 2.5 (Measurement Principle). Note that stages end 10 seconds before a valve is switched to avoid transients

red2$stage<- "shed"

red2$stage[red2$seconds_inhour>= 110 & red2$seconds_inhour<= 170]<-"lowstd"

red2$stage[red2$seconds_inhour>= 290 & red2$seconds_inhour<= 350]<-"histd"

red2$stage[(red2$seconds_inhour>= 530& red2$seconds_inhour<= 650)]<-"inlet1_ChA"

red2$stage[(red2$seconds_inhour>= 1130 & red2$seconds_inhour<= 1250)]<-"inlet2_ChA"

red2$stage[(red2$seconds_inhour>= 830 & red2$seconds_inhour<= 950)]<-"outlet1_ChA"

red2$stage[(red2$seconds_inhour>= 1600 & red2$seconds_inhour<= 1720)]<-"outlet2_ChA"

## for second Ch during the hour
red2$stage[(red2$seconds_inhour>= 2330& red2$seconds_inhour<= 2450)]<-"inlet1_ChB"

red2$stage[(red2$seconds_inhour>= 2930 & red2$seconds_inhour<= 3050)]<-"inlet2_ChB"

red2$stage[(red2$seconds_inhour>= 2630 & red2$seconds_inhour<= 2750)]<-"outlet1_ChB"

red2$stage[(red2$seconds_inhour>= 3400 & red2$seconds_inhour<= 3520)]<-"outlet2_ChB"



#create a unique label for each date/hour and stage
red2$date.hour.stage <-paste(red2$date.hour, red2$stage)

# average a number of response variables by date/hour and stage, also including panel temperature and battery voltage as these variables can be useful diagnostics

ag<- aggregate(cbind(N2O_ppm_Avg, CO2_ppm_IRGA_Avg, AirTC_Avg, PanTemp_Avg, InletFlow_Avg, ChFlow_Avg, SampleFlow_Avg, batt_volt_Avg, cum.hours, CycleType_Avg)~date.hour.stage +date.hour+stage+hour+cal.hour, red2, mean, na.rm=TRUE)


#Calculate standard deviations by the same criteria, also can be useful diagnostics
agsd<-aggregate(cbind(N2O_ppm_Avg, CO2_ppm_IRGA_Avg, AirTC_Avg, PanTemp_Avg, InletFlow_Avg, ChFlow_Avg, SampleFlow_Avg, batt_volt_Avg, cum.hours, CycleType_Avg)~date.hour.stage +date.hour+stage+hour+ cal.hour, red2, sd, na.rm=TRUE)

#combine the sd's and means in the same data frame
ag$N2O_ppm_sd<-agsd$N2O_ppm_Avg
ag$CO2_ppm_sd<-agsd$CO2_ppm_IRGA_Avg
ag$ChFlow_sd<-agsd$ChFlow_Avg
ag$InletFlow_sd<-agsd$InletFlow_Avg
ag$SampleFlow_sd<-agsd$SampleFlow_Avg


#redefine a timestamp for the stage averaged data, because the previous timestamp format was altered by the aggregate function
ag$stage<-as.factor(ag$stage)
ag$time<-as.POSIXct(strptime(ag$date.hour, "%Y-%m-%d %H"))
ag$date<-as.POSIXct(strptime(ag$date.hour, "%Y-%m-%d"))

#sort dataframe in order of timestamps
ag<-ag[order(ag$time),]

## verify consistent sample flow by stage; want to be roughly equivalent for histd, inlet, lowstd, outlet. Subtle differences arise because of how the needle valves are adjusted on the excess vents for each line. these differences are OK as long as the sample flows are >850 and <900 and ChFlow (outlet) and inlet flows are >1700. Shed flow, other than sample flow, can be disregarded. These plots are useful to diagnose failed valves, wiring issues, or wet filters at the chamber (all can result in lower than normal flow rates)

#make boxplots of flow rates by stage
plot(SampleFlow_Avg~stage, ag)
plot(ChFlow_Avg ~stage, ag)
plot(InletFlow_Avg ~stage, ag)

#define a "cycle" as a group of measurements from each pair of hours where the std curve from that two-hour period will be applied.
#ag$cycle<-as.numeric(as.factor(ag$time))
ag$cycle<-as.numeric(as.factor(paste(ag$date, ag$cal.hour)))

#eliminate partial cycles at beginning and end for simplicity. You might want to combine multiple .csv files for analysis to avoid eliminating partial cycles

#ag<-ag[ag$cycle>1 & ag$cycle<length(unique(ag$cycle)),]

#eliminate missing factor levels
ag<-droplevels(ag)

#### Standard Correction

#define analyte concentrations in standard tanks (units of ppm). Here we take the measured values from the average of five subsamples analyzed on a gas chromatograph. It's useful to note when standards are changed in your cleaning code. Because we make working standard tanks in our lab, the precise values change each time a tank is replaced

#New Standards instaled 10/23/2018 
#Lowstd CO2=498, N2O=.263
#Histd  CO2=1656 N2O=1.92

lowstd_CO2<- 498
histd_CO2<-1656

lowstd_N2O<-.263
histd_N2O<-1.92



# define reduced dataset created with only standards
stds<-ag[ag$stage=="lowstd" | ag$stage=="histd", ]

#eliminate hours where stds were not measured (remember, we measure standards every two hours)
stds<-stds[(stds$hour!=1 & stds$hour!=3 & stds$hour!=5 & stds$hour!=7 & stds$hour!=9 & stds$hour!=11 & stds$hour!=13 & stds$hour!=15 & stds$hour!=17 & stds$hour!=19 & stds$hour!=21 & stds$hour!=23),]

#define placeholder columns for known std values, these will be replaced 
stds$N2O_known<- -999
stds$CO2_known<- -999

# define the standard values for each stage based on the values input above
stds$N2O_known[stds$stage=="lowstd"]<- lowstd_N2O
stds$N2O_known[stds$stage=="histd"]<- histd_N2O

stds$CO2_known[stds$stage=="lowstd"]<- lowstd_CO2
stds$CO2_known[stds$stage=="histd"]<- histd_CO2


#plot the global std curves, note that the N2O output shows slightly more variability, this is due to temperature sensitivity.

plot(N2O_known ~ N2O_ppm_Avg, stds)
plot(CO2_known ~ CO2_ppm_IRGA_Avg, stds)

# plot stds over time, note that both high and low standard output for N2O varies in a similar shape and magnitude. Temperature sensitivity is due to drift of the regression intercept, while slope remains fairly constant. See section 3.2 (Measurement Assumptions)
plot(N2O_ppm_Avg ~ time, stds)
plot(CO2_ppm_IRGA_Avg ~ time, stds)

#make a dataframe with the subset of cycles where standards are measured
ag<-ag[(ag$cycle %in% stds$cycle),]

##### generate calibrated data using cycle-specific std curves

## We use the nlme package - function lmList, which calculates a linear model for a given group of data; here, we specify discrete linear models for each "cycle"


# make a list of linear models for each cycle; 
llN2O<-lmList(N2O_known ~ (N2O_ppm_Avg)|cycle, data=stds)
llCO2<-lmList(CO2_known ~ (CO2_ppm_IRGA_Avg)|cycle, data=stds)

#calculate calibrated values for the aggregated data using the standard curve from each cycle
ag$N2O_ppm_cor <-predict(llN2O,ag)
ag$CO2_ppm_cor<-predict(llCO2,ag)

#Store the coefficients of the linear models in lists. We'll keep these in the final dataset, as it is useful to observe how the slope and intercept of the instruments changes over long periods. 

N2Odf <- coef(llN2O)
CO2df <- coef(llCO2)


#Add cycle identifier to the coefficients that we can use to match the regression coefficients 
N2Odf2 <- cbind(rownames(N2Odf), data.frame(N2Odf, row.names=NULL))

#Subset desired variables
colnames(N2Odf2) <- c("cycle", "N2OIntercept", "N2OSlope")

#Repeat for CO2
CO2df2 <- cbind(rownames(CO2df), data.frame(CO2df, row.names=NULL))

colnames(CO2df2) <- c("cycle", "CO2Intercept", "CO2Slope")

#Now we add these coefficients to the aggregated dataset

ag2 <- merge(ag, N2Odf2, by="cycle")
ag3 <- merge(ag2, CO2df2, by="cycle")

#define chamber number based on hour of day, we need this to associate chamber flux at the top or bottom of the hour to a specific auto-chamber

#first create placeholder
ag3$chamber<-ag3$hour

# Define measurements at top of the hour (this is simply from the table above which defines which chamber measures at which time)
ag3$chamber[ag3$hour==0]<-1
ag3$chamber[ag3$hour==1]<-3
ag3$chamber[ag3$hour==2]<-2
ag3$chamber[ag3$hour==3]<-4
ag3$chamber[ag3$hour==4]<-1
ag3$chamber[ag3$hour==5]<-3
ag3$chamber[ag3$hour==6]<-2
ag3$chamber[ag3$hour==7]<-4
ag3$chamber[ag3$hour==8]<-1
ag3$chamber[ag3$hour==9]<-3
ag3$chamber[ag3$hour==10]<-2
ag3$chamber[ag3$hour==11]<-4
ag3$chamber[ag3$hour==12]<-1
ag3$chamber[ag3$hour==13]<-3
ag3$chamber[ag3$hour==14]<-2
ag3$chamber[ag3$hour==15]<-4
ag3$chamber[ag3$hour==16]<-1
ag3$chamber[ag3$hour==17]<-3
ag3$chamber[ag3$hour==18]<-2
ag3$chamber[ag3$hour==19]<-4
ag3$chamber[ag3$hour==20]<-1
ag3$chamber[ag3$hour==21]<-3
ag3$chamber[ag3$hour==22]<-2
ag3$chamber[ag3$hour==23]<-4

#Now we replace chamber values from the second half of the hour (Chamber B) with the appropriate values
#We utilize the second inlet/outlet measurements for calculation of chamber flux. We retain outlet 1 values as a diagnostic (specifically testing how quickly the chambers reach equilibrium)

ag3$chamber[ag3$hour==0 & grepl("ChB", ag3$stage)]<-5
ag3$chamber[ag3$hour==1  & grepl("ChB", ag3$stage)]<-7
ag3$chamber[ag3$hour==2  & grepl("ChB", ag3$stage)]<-6
ag3$chamber[ag3$hour==3 & grepl("ChB", ag3$stage)]<-8
ag3$chamber[ag3$hour==4 & grepl("ChB", ag3$stage)]<-5
ag3$chamber[ag3$hour==5 & grepl("ChB", ag3$stage)]<-7
ag3$chamber[ag3$hour==6 & grepl("ChB", ag3$stage)]<-6
ag3$chamber[ag3$hour==7 & grepl("ChB", ag3$stage)]<-8
ag3$chamber[ag3$hour==8 & grepl("ChB", ag3$stage)]<-5
ag3$chamber[ag3$hour==9 & grepl("ChB", ag3$stage)]<-7
ag3$chamber[ag3$hour==10 & grepl("ChB", ag3$stage)]<-6
ag3$chamber[ag3$hour==11 & grepl("ChB", ag3$stage)]<-8
ag3$chamber[ag3$hour==12 & grepl("ChB", ag3$stage)]<-5
ag3$chamber[ag3$hour==13 & grepl("ChB", ag3$stage)]<-7
ag3$chamber[ag3$hour==14 & grepl("ChB", ag3$stage)]<-6
ag3$chamber[ag3$hour==15 & grepl("ChB", ag3$stage)]<-8
ag3$chamber[ag3$hour==16 & grepl("ChB", ag3$stage)]<-5
ag3$chamber[ag3$hour==17 & grepl("ChB", ag3$stage)]<-7
ag3$chamber[ag3$hour==18 & grepl("ChB", ag3$stage)]<-6
ag3$chamber[ag3$hour==19 & grepl("ChB", ag3$stage)]<-8
ag3$chamber[ag3$hour==20 & grepl("ChB", ag3$stage)]<-5
ag3$chamber[ag3$hour==21 & grepl("ChB", ag3$stage)]<-7
ag3$chamber[ag3$hour==22 & grepl("ChB", ag3$stage)]<-6
ag3$chamber[ag3$hour==23 & grepl("ChB", ag3$stage)]<-8

#make a reduced dataframe with variables needed for gas flux calculations
agred<-ag3[,c("date.hour", "stage", "hour", "AirTC_Avg","ChFlow_Avg","time","cycle","N2O_ppm_cor","CO2_ppm_cor","chamber", "N2O_ppm_sd","CO2_ppm_sd", "N2O_ppm_Avg","N2OIntercept","N2OSlope", "CO2_ppm_IRGA_Avg","CO2Intercept","CO2Slope" )]


#condense inlet-outlet name for ChA and ChB (top of hour and half hour) to one ID variable for efficiency 
agred$stage<-as.character(agred$stage) # change factor to character to reassign
agred$stage[agred$stage=="inlet1_ChA"]<-"inlet1"
agred$stage[agred$stage=="inlet1_ChB"]<-"inlet1"
agred$stage[agred$stage=="inlet2_ChA"]<-"inlet2"
agred$stage[agred$stage=="inlet2_ChB"]<-"inlet2"
agred$stage[agred$stage=="outlet1_ChA"]<-"outlet1"
agred$stage[agred$stage=="outlet1_ChB"]<-"outlet1"
agred$stage[agred$stage=="outlet2_ChA"]<-"outlet2"
agred$stage[agred$stage=="outlet2_ChB"]<-"outlet2"
agred$stage<-as.factor(agred$stage) #change back to a factor

#transform data to "wide" format for easy calculations using the "reshape" package. The ID variables are defined as follows.
ag1<-melt(agred, c("date.hour","stage","hour","time","cycle","chamber"))
ag3<-cast(ag1, date.hour + time + hour + cycle + chamber~ stage + variable)


#evaluate trends in inlet concentrations of gases
#N2O analyzer output is impacted by temperature as decribed in Section 3.2 "Measurement Assumptions" If temperature changes very rapidly, output can drift over the course of one chamber measurement. These values can be identified by the difference between inlet1 and inlet2 for each chamber, the ambient drift in N2O concentration over a ~20 minute period should be <.03 ppm (this is because we do not expect large temporal variation in ambient N2O concentrations outside the chambers)

ag3$Inlet_N2O_Diff[!is.na(ag3$inlet1_N2O_ppm_cor) & !is.na(ag3$inlet2_N2O_ppm_cor)] <- (ag3$inlet2_N2O_ppm_cor[!is.na(ag3$inlet1_N2O_ppm_cor) & !is.na(ag3$inlet2_N2O_ppm_cor)]-ag3$inlet1_N2O_ppm_cor[!is.na(ag3$inlet1_N2O_ppm_cor) & !is.na(ag3$inlet2_N2O_ppm_cor)])

#These values are realistic
plot(Inlet_N2O_Diff~time, ag3)




####
#### calculate gas fluxes 

#unit for N2O flux is ug N2O-N m-2 h-1 
#unit for CO2 flux is umol CO2-C m-2 s-1 (for easy comparison with LiCOR 8100) 

# use the air temp measured outside the shed to calculate moles of gas per liter (which is assumed to represent the air in the chambers); add 273.15 to transform Kelvin to Celsius

# 0.082 is the ideal gas constant, units L atm / K mol
R<-0.08206

# mean atmospheric pressure is 0.97 atm at Ames  (287 m); note that this varies with the weather system, but sensitivity of this calculation to pressure variation is small (standard deviation of pressure measured at the Ames airport was 0.007 atm from 2017 to 2019)
patm<-0.97

# to get flow through chamber on a mol basis : PV / RT = moles; flow rate is reported as ml / min

# chamber area: 12" nominal PVC, real ID 11.94", radius = 15.16 cm; area = 3.14* 15.16^2 = 722 cm^2 = 722/10000 = 0.0722 m^2

##CO2
# flow(ml / min) x (1 L / 1000 ml) x (1/60 min / sec) x pressure(atm)/(R (L atm / K mol) x T(K)) x CO2 concentration (umol/mol)  / 0.0722 m^2 
##N2O
# flow(ml / min) x (1 L / 1000 ml) x (60 min / hr) x pressure(atm)/(R (L atm / K mol) x T(K)) x CO2 concentration (umol/mol) x 14*2 g N/mol  / 0.0722 m^2

ag3$CO2flux_umol_m2_s<- (ag3$outlet2_ChFlow_Avg*(1/1000)*1/60*patm/(R*(ag3$outlet2_AirTC_Avg +273.15)))*(ag3$outlet2_CO2_ppm_cor-ag3$inlet2_CO2_ppm_cor)/ 0.0722

ag3$N2Oflux_ug_N2ON_m2_hr<- (ag3$outlet2_ChFlow_Avg*(1/1000)*60*patm/(R*(ag3$outlet2_AirTC_Avg +273.15)))*(ag3$outlet2_N2O_ppm_cor-ag3$inlet2_N2O_ppm_cor)*14*2 / 0.0722


#Now we can put the data in chronological order
ag4<-ag3[order(ag3$time),]

#To diagnose flow issues with individual chambers, we can plot the flow rates here. Values should be >1900 and <2000 ml/min.

plot(ag4$outlet2_ChFlow_Avg~ag4$chamber)
plot(ag4$inlet2_ChFlow_Avg~ag4$chamber)


#If individual chambers are not operational (perhaps due to wet filters or other issues, we can easily drop them here
#During this period, a faulty valve prevented Chamber 8 from properly closing
ag4<-ag4[ag4$chamber !=8,]

#write data to a csv for further examination if desired
# write.csv(ag4, "ag4.csv", row.names=FALSE)

#Now we can plot the final fluxes

plot(CO2flux_umol_m2_s~time, ag4)
plot(ag4$inlet2_AirTC_Avg~time, ag4)

#Assess variation among the chambers
plot(CO2flux_umol_m2_s ~chamber, ag4)

plot(N2Oflux_ug_N2ON_m2_hr ~chamber, ag4)
plot(N2Oflux_ug_N2ON_m2_hr ~time, ag4)

